@@ -1,5 +1,8 @@
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from typing import Any, cast, Union
+
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import CreateMixin, RetrieveMixin, SaveMixin, UpdateMixin
+from gitlab.types import RequiredOptional
 
 from .merge_requests import ProjectDeploymentMergeRequestManager  # noqa: F401
 
@@ -10,11 +13,11 @@ __all__ = [
 
 
 class ProjectDeployment(SaveMixin, RESTObject):
-    _managers = (("mergerequests", "ProjectDeploymentMergeRequestManager"),)
+    mergerequests: ProjectDeploymentMergeRequestManager
 
 
 class ProjectDeploymentManager(RetrieveMixin, CreateMixin, UpdateMixin, RESTManager):
-    _path = "/projects/%(project_id)s/deployments"
+    _path = "/projects/{project_id}/deployments"
     _obj_cls = ProjectDeployment
     _from_parent_attrs = {"project_id": "id"}
     _list_filters = (
@@ -28,3 +31,8 @@ class ProjectDeploymentManager(RetrieveMixin, CreateMixin, UpdateMixin, RESTMana
     _create_attrs = RequiredOptional(
         required=("sha", "ref", "tag", "status", "environment")
     )
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectDeployment:
+        return cast(ProjectDeployment, super().get(id=id, lazy=lazy, **kwargs))
